<?php

class ShipmendoLite {
	public $plugin_file;
	public static $wp_sms_functions_url = "https://wordpress.org/plugins/wp-sms-functions/";

	public function __construct() {
		$this->plugin_file = dirname( __FILE__ ) . '/shipmendo-lite.php';
		register_activation_hook( $this->plugin_file, array( $this, 'plugin_activate' ) );
		register_deactivation_hook( $this->plugin_file, array( $this, 'plugin_deactivate' ) );
		add_action( 'admin_menu', array( $this, 'menu_init' ) );
		add_action( 'admin_init', array( $this, 'save_order' ) );
		add_action( 'init', array( $this, 'register_order_status' ) );
		add_filter( 'wc_order_statuses', array( $this, 'shipped_order_status' ) );
		add_action( 'woocommerce_my_account_my_orders_column_order-status', array( $this, 'orders_status_edit' ) );
		add_action( 'add_meta_boxes', array( $this, 'tracking_box' ) );
		add_action( 'save_post', array( $this, 'save_cargo_tracking_number' ), 1 );
		add_action( 'woocommerce_order_status_changed', array( $this, 'send_sms_email' ), 99 );
		add_filter( 'woocommerce_email_classes', array( $this, 'email_class' ) );
		add_action( 'woocommerce_view_order', array( $this, 'add_shipping_details' ), 1, 100 );
        add_action( 'admin_enqueue_scripts', array( $this, 'load_assets' ) );
	}

	public function plugin_activate() {
		add_option( '_cargo_tracking_default_cargo_company', 'mng' );
		add_option( '_cargo_tracking_email_enabled', 'on' );
		add_option( '_cargo_tracking_sms_message', __( 'Dear {customer_name}, Your order(#{order_number}) shipped with {cargo_company_info}. To track your shipping: {url}', 'shipmendo-lite' ) );
	}

	public function plugin_deactivate() {
		delete_option( '_cargo_tracking_default_cargo_company' );
		delete_option( '_cargo_tracking_sms_message' );
		delete_option( '_cargo_tracking_sms_enabled' );
		delete_option( '_cargo_tracking_email_enabled' );
	}

	public function load_assets() {
		wp_register_style( 'cargo_tracking_admin_css', gl_get_shipmendo_plugin_assets( '/css/shipmendo-lite-admin.css' ), false, '1.0.0' );
		wp_enqueue_style( 'cargo_tracking_admin_css' );
		if ( filter_input( 1, 'page', FILTER_SANITIZE_STRING ) === "shipmendo-lite" ) {
			wp_enqueue_script( 'cargo_tracking_admin_js', gl_get_shipmendo_plugin_assets( '/js/admin.js' ), array() );
		}
	}

	public function menu_init() {
		add_menu_page(
			__( 'shipmendo - Lite', 'shipmendo-lite' ),
			__( 'shipmendo - Lite', 'shipmendo-lite' ),
			'manage_options',
			'shipmendo-lite',
			array( $this, 'ship_tracking_content' ),
			gl_get_shipmendo_plugin_assets( '/images/shipmendo-small-icon.png' ),
			55.3 );
	}

	public function get_shortcodes() {
		$shortcodes = array(
			array(
				'label' => __( 'Customer Name', 'shipmendo-lite' ),
				'code'  => 'customer_name'
			),
			array(
				'label' => __( 'Order Number', 'shipmendo-lite' ),
				'code'  => 'order_number'
			),
			array(
				'label' => __( 'Order ID', 'shipmendo-lite' ),
				'code'  => 'order_id'
			),
			array(
				'label' => __( 'Tracking Number', 'shipmendo-lite' ),
				'code'  => 'tracking_number'
			),
			array(
				'label' => __( 'Company Name', 'shipmendo-lite' ),
				'code'  => 'cargo_company_info'
			),
			array(
				'label' => __( 'Tracking URL', 'shipmendo-lite' ),
				'code'  => 'url'
			)
		);

		return $shortcodes;
	}

	public function ship_tracking_content() {
		$trackingSMSMessage = gl_shipmendo_get_cargo_sms_message();

		try {
			require dirname( __FILE__ ) . '/lib/Grilabs_promotions.php';
			$promo = new Grilabs_promotions();
			$ads   = $promo->get_data();
		} catch ( \Exception $exception ) {
		}
		?>

        <link rel="preconnect" href="https://fonts.googleapis.com">
        <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
        <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap" rel="stylesheet">
        <div id="shipmendo-container">
            <nav class="shipmendo-lite-top-navbar">
                <div class="shipmendo-lite-top-navbar-div">
                    <ul class="shipmendo-lite-top-navbar-ul">
                        <li class="shipmendo-lite-top-navbar-nav-item">
                            <a class="shipmendo-lite-top-navbar-nav-link"
                               href="<?php echo admin_url( 'admin.php?page=shipmendo-lite' ) ?>">
                                <img width="15"
                                     src="<?php echo gl_get_shipmendo_plugin_assets( '/images/settings.svg' ) ?>"
                                     alt=""/>
								<?php _e( 'Settings', 'shipmendo-lite' ) ?>
                            </a>
                        </li>
                        <li class="shipmendo-lite-top-navbar-nav-item">
                            <a class="shipmendo-lite-top-navbar-nav-link" href="https://www.gri.net/" target="_blank">
                                <img width="15"
                                     src="<?php echo gl_get_shipmendo_plugin_assets( '/images/help.svg' ) ?>"/>
								<?php _e( 'Support', 'shipmendo-lite' ) ?>
                            </a>
                        </li>
                        <li class="shipmendo-lite-top-navbar-nav-item shipmendo-upgrade-button">
                            <a class="shipmendo-lite-top-navbar-nav-link"
                               href="https://www.gri.net/wordpress-eklentileri/?focus=shipping" target="_blank">
                                <img width="15"
                                     src="<?php echo gl_get_shipmendo_plugin_assets( '/images/up-arrow.png' ) ?>"/> <?php _e( 'Upgrade Now', 'shipmendo-lite' ) ?>
                            </a>
                        </li>
                    </ul>
                </div>

                <div class="grilabs-logo">
                    <a href="https://www.shipmendo.com" target="_blank"><img
                                src="<?php echo gl_get_shipmendo_plugin_assets( '/images/shipmendo-transparent-logo.png' ); ?>"
                                height="30" style=""/></a>
                </div>
            </nav>
            <div class="shipmendo-plugin-content">
                <p><?php echo __( 'This Wordpress plugin allows you share the shipping process of your orders with WooCommerce. You can ensure a more effective use by completing the following settings.', 'shipmendo-lite' ) ?></p>

                <div style="opacity: 0;">
                    <input id="shipmendo-lite-copy-area" type="text" name="" value=""/>
                </div>
                <form method="POST">
                    <table width="100%" class="shipmendo-lite-settings-table" cellpadding="10">
                        <tbody>
						<?php
						$sms_functions_enabled = function_exists( 'wp_sms_send_sms' );
						if ( $sms_functions_enabled ) {
							?>
                            <tr>
                                <th width="250">
                                    <label for="enable_sms"><?php echo __( 'Enable SMS Notification:', 'shipmendo-lite' ) ?></label>
                                </th>
                                <td>
                                    <input type="checkbox" id="enable_sms" name="enable_sms"
                                           value="on"
										<?php echo gl_shipmendo_is_cargo_sms_enabled() ? "checked" : "" ?>
                                    />
                                </td>
                            </tr>
                            <tr id="sms-message-template-setting" style="<?php
							echo gl_shipmendo_is_cargo_sms_enabled() ? "" : "display:none"
							?>">
                                <th width="250">
                                    <label for="sms_message"><?php echo __( 'SMS Message Template:', 'shipmendo-lite' ) ?></label>
                                </th>
                                <td>
                            <textarea id="sms_message" class="large-text "
                                      name="sms_message"><?php echo $trackingSMSMessage ?></textarea>
                                    <ul>
                                        <li class="shortlist-title"><?php echo __( 'Available Shortcodes:', 'shipmendo-lite' ) ?></li>
										<?php
										foreach ( $this->get_shortcodes() as $shortcode ) {
											echo sprintf( "<li><strong onclick='cargo_tracking_insert2input(\"{%s}\")'>{%s}</strong>: %s</li>", $shortcode['code'], $shortcode['code'], $shortcode['label'] );
										}
										?>
                                    </ul>
                                </td>
                            </tr>
							<?php
						} else {
							?>
                            <div class="notice notice-error">
                                <p><?php echo sprintf( __( 'Get the <a href="%s">"WP SMS Functions"</a> plugin to activate the SMS sending feature.', 'shipmendo-lite' ), self::$wp_sms_functions_url ); ?></p>
                            </div>
							<?php
						}
						?>

                        <tr>
                            <th width="250">
                                <label for="enable_email"><?php echo __( 'Enable Email Notification:', 'shipmendo-lite' ) ?></label>
                            </th>
                            <td>
                                <input type="checkbox" id="enable_email" name="enable_email"
                                       value="on"
									<?php echo gl_shipmendo_is_cargo_email_enabled() ? "checked" : "" ?>
                                />
                            </td>
                        </tr>

                        <tr>
                            <th width="250">
                                <label for="_cargo_tracking_default_cargo_company"><?php echo __( 'Default Shipment Company', 'shipmendo-lite' ); ?></label>
                            </th>
                            <td>
                                <select name="_cargo_tracking_default_cargo_company"
                                        id="_cargo_tracking_default_cargo_company">
									<?php
									$companies = gl_shipmendo_get_cargo_companies();
									foreach ( $companies as $company ): ?>
                                        <option value="<?php echo $company->getSlug() ?>"
											<?php echo gl_shipmendo_get_cargo_default_company_name() !== null &&
											           gl_shipmendo_get_cargo_default_company_name() === $company->getSlug()
												? 'selected'
												: null ?>>
											<?php echo __( $company->getName(), 'shipmendo-lite' ) ?>
                                        </option>
									<?php endforeach; ?>
                                </select>
                            </td>
                        </tr>

                        <tr>
                            <th width="150">&nbsp;</th>
                            <td>
                                <p>&nbsp;</p>
                                <input type="submit" name="submit" class="button-primary"
                                       value="<?php echo __( 'Save Changes', 'shipmendo-lite' ) ?>">
                            </td>
                        </tr>
                        </tbody>
                    </table>
                </form>
            </div>

			<?php
			if ( isset( $ads ) && is_array( $ads ) && $ads ) {
				?>
                <div class="grilabs-ads">
                    <div class="promo-text">
                        <img width="35" src="<?php echo gl_get_shipmendo_plugin_assets( '/images/up-arrow.png' ) ?>"/>
                        <p>
							<?php
							echo sprintf( __( 'You can <b>fully automated</b> the shipping processes on your WooCommerce website. <a class="button" href="%s" target="_blank">%s</a>', 'shipmendo-lite' ), 'https://www.gri.net/wordpress-eklentileri/?focus=shipping', __( 'Upgrade Now', 'shipmendo-lite' ) );
							?>
                        </p>
                    </div>
                    <div class="ad-list">
						<?php
						foreach ( $ads as $ad ) {
							echo '<div class="single-ad">' .
							     '<a href="' . $ad->url . '" target="_blank"><img src="' . $ad->image . '"/></a>' .
							     '</div>';
						}
						?>
                    </div>
                </div>
				<?php
			}
			?>
        </div>
		<?php
	}

	public function save_order() {
        if ( isset( $_POST['sms_message'] ) || isset( $_POST['_cargo_tracking_default_cargo_company'] ) ) {
            $smsMessage   = isset($_POST['sms_message']) ? $_POST['sms_message'] : '';
			$defCargoNew  = $_POST['_cargo_tracking_default_cargo_company'];
			$smsEnabled   = isset( $_POST['enable_sms'] ) ? "on" : 'off';
			$emailEnabled = isset( $_POST['enable_email'] ) ? "on" : 'off';
			update_option( '_cargo_tracking_sms_message', $smsMessage );
			update_option( '_cargo_tracking_sms_enabled', $smsEnabled );
			update_option( '_cargo_tracking_email_enabled', $emailEnabled );
			update_option( '_cargo_tracking_default_cargo_company', $defCargoNew );
		}
	}

	public function register_order_status() {
		register_post_status( 'wc-shipped2', array(
			'label'                     => __( 'Shipped', 'shipmendo-lite' ),
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => true,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Shipped (%s)', 'Shipped (%s)', 'shipmendo-lite' )
		) );
	}

	public function shipped_order_status( $order_statuses ) {
		$new_order_statuses = array();
		foreach ( $order_statuses as $key => $status ) {
			$new_order_statuses[ $key ] = $status;
			if ( 'wc-processing' === $key ) {
				$new_order_statuses['wc-shipped2'] = __( 'Shipped', 'shipmendo-lite' );
			}
		}

		return $new_order_statuses;
	}

	public function orders_status_edit( WC_Order $order ) {
		$orderStatus = $order->get_status();
		$statusName  = esc_html( wc_get_order_status_name( $order->get_status() ) );
		if ( $orderStatus !== 'shipped2' ) {
			echo $statusName;

			return;
		}
		$tracking_url = gl_shipmendo_get_order_cargo_tracking_url( $order->get_id() );
		$gateway      = gl_shipmendo_get_order_cargo_company_info( $order->get_id() );
		if ( ! $gateway ) {
			return;
		}
		$gateway_object = gl_shipmendo_get_cargo_companies( $gateway );
		$output         = '<div>' .
		                  $statusName .
		                  '<a style="text-decoration:none; display:block" href="' . $tracking_url . '" target="_blank">' .
		                  '<img style="display:inline-block" src="' . $gateway_object->getLogo() . '" width="50" />' .
		                  '</a>' .
		                  '</div>';
		echo apply_filters( 'gl_shipmendo_my_account_output', $output );
	}

	public function tracking_box() {
		add_meta_box(
			'tracking-box-modal',
			__( 'Shipment Details', 'shipmendo-lite' ),
			array( $this, 'tracking_box_callback' ),
			'shop_order',
			'side' );
	}

	public function tracking_box_callback( $post ) {
		$trackingNumber   = gl_shipmendo_get_order_cargo_tracking_number( $post->ID );
		$cargoCompanyInfo = gl_shipmendo_get_order_cargo_company_info( $post->ID );
		$cargo_companies  = gl_shipmendo_get_cargo_companies();
		?>
        <div class="shipmendo-lite-box">
            <div class="cargo-companies">
				<?php
				foreach ( $cargo_companies as $cargo_company ) {
					echo sprintf( "<div class='single-cargo-company'>" .
					              "<label>" .
					              "<input type='radio' name='cargo_company_info' value='%s'%s/>" .
					              "<span><strong>%s</strong><img src='%s' /></span>" .
					              "</label>" .
					              "</div>",
						$cargo_company->getSlug(),
						$cargoCompanyInfo === $cargo_company->getSlug() ? " checked" : null,
						$cargo_company->getName(), $cargo_company->getLogo()
					);
				}
				?>
            </div>
            <div class="tracking-number-input">
                <label><?php echo __( 'Tracking Number', 'shipmendo-lite' ) ?></label>
                <input type="text" name="cargo_tracking_number" value="<?php echo $trackingNumber ?>"/><br><br>
            </div>
            <?php if (!$trackingNumber): ?>
                <div class="tracking-status-input">
                    <input type="checkbox" value="yes" name="tracking_change_status" id="tracking-change-status">
                    <label for="tracking-change-status"><?php echo __('Update order status as Shipped.') ?></label>
                </div>
            <?php endif; ?>
			<?php echo ( $trackingNumber && $cargoCompanyInfo ) ? '<div style="width:100%; text-align: center"><a style="text-decoration: none" href="' . gl_shipmendo_get_cargo_tracking_url( $cargoCompanyInfo, $trackingNumber ) . '" target="_blank">' . __( 'Track Order' ) . ' <span class="dashicons dashicons-external"></span></a></div>' : '' ?>

        </div>
		<?php
	}

	public function save_cargo_tracking_number( $post_id ) {
		$trackingNumber   = gl_shipmendo_get_order_cargo_tracking_number( $post_id );
		$cargoCompanyInfo = gl_shipmendo_get_order_cargo_company_info( $post_id );
		if ( filter_input( 0, 'cargo_tracking_number', FILTER_SANITIZE_STRING ) ) {
			$trackingNumberPost = filter_input( 0, 'cargo_tracking_number', FILTER_SANITIZE_STRING );
			if ( $trackingNumber !== $trackingNumberPost ) {
				update_post_meta( $post_id, '_cargo_tracking_number', $trackingNumberPost );
			}

			$cargoCompanyInfoPost = filter_input( 0, 'cargo_company_info', FILTER_SANITIZE_STRING );
			if ( $cargoCompanyInfo !== $cargoCompanyInfoPost ) {
				update_post_meta( $post_id, '_cargo_company_info', $cargoCompanyInfoPost );
			}

            $is_status_will_change = isset($_POST['tracking_change_status']) && $_POST['tracking_change_status'] === 'yes';
            if ($is_status_will_change) {
                $order = wc_get_order($post_id);
                $status = $order->get_status();
                if ($status !== 'shipped2') {
                    $_POST['order_status'] = 'shipped2';
                    $order->update_status($_POST['order_status']);
                }
            }
		}
	}

	public function send_sms_email( $post_id ) {
		$order  = wc_get_order( $post_id );
		$status = $order->get_status();
		if ( $status !== 'shipped2' ) {
			return;
		}
		gl_shipmendo_send_sms( $post_id );
		gl_shipmendo_send_email( $post_id, $status );
	}

	public function email_class( $actions ) {
		$actions['Shipped_Order'] = include_once( 'emails/shipped-order.php' );

		return $actions;
	}

	public function add_shipping_details( $order_id ) {
		$order  = wc_get_order( $order_id );
		$status = $order->get_status();
		if ( $status !== 'shipped2' ) {
			return;
		}
		$tracking_number = gl_shipmendo_get_order_cargo_tracking_number( $order->get_id() );
		$tracking_url    = gl_shipmendo_get_order_cargo_tracking_url( $order->get_id() );
		$gateway         = gl_shipmendo_get_order_cargo_company_info( $order->get_id() );
		if ( ! $gateway ) {
			return;
		}
		$gateway_object = gl_shipmendo_get_cargo_companies( $gateway );
		echo '<table border="0" cellpadding="5">' .
		     '<tbody>' .
		     '<tr>' .
		     '<th width="200">' . __( 'Shipping Company', 'shipmendo-lite' ) . '</th>' .
		     '<td><img src="' . $gateway_object->getLogo() . '" width="70" /><strong>' . $gateway_object->getName() . '</strong></td>' .
		     '</tr>' .
		     '<tr>' .
		     '<th width="200">' . __( 'Tracking Number', 'shipmendo-lite' ) . '</th>' .
		     '<td>' . $tracking_number . '</td>' .
		     '</tr>' .
		     '<tr>' .
		     '<th width="200">&nbsp;</th>' .
		     '<td><a class="button" href="' . $tracking_url . '" target="_blank">' . __( 'Track Order', 'shipmendo-lite' ) . '</a></td>' .
		     '</tr>' .
		     '</tbody>' .
		     '</table>';
	}
}