<?php

class ShippedOrder extends WC_Email {
	public function __construct() {
		$this->id             = 'shipped_order';
		$this->customer_email = true;
		$this->title          = __( 'Order has been shipped!', 'shipmendo-lite' );
		$this->description    = __( 'This email is received when an order status is changed to Shipped.', 'shipmendo-lite' );
		$this->template_base  = __DIR__;
		$this->template_html  = '/templates/admin-shipped-order.php';

		parent::__construct();

	}

	public function get_default_subject() {
		return __( '[{site_title}]: Order has been shipped #{order_number}', 'shipmendo-lite' );
	}

	public function get_default_heading() {
		return __( 'Order has been shipped: #{order_number}', 'shipmendo-lite' );
	}

	public function get_default_additional_content() {
		return '';
	}

	public function get_content_html() {
		$obj                = $this->object;
		$cargo_company_info = gl_shipmendo_get_order_cargo_company_info( $obj->get_id() );
		$cargo_comp_obj     = gl_shipmendo_get_cargo_companies( $cargo_company_info );

		return wc_get_template_html(
			$this->template_html,
			array(
				'order'              => $obj,
				'tracking_url'       => gl_shipmendo_get_order_cargo_tracking_url( $obj->get_id() ),
				'cargo_company_name' => $cargo_comp_obj->getName(),
				'tracking_number'    => gl_shipmendo_get_order_cargo_tracking_number( $obj->get_id() ),
				'cargo_company_logo' => $cargo_comp_obj->getLogo(),
				'email_heading'      => $this->get_heading(),
				'additional_content' => $this->get_additional_content(),
				'sent_to_admin'      => false,
				'plain_text'         => false,
				'email'              => $this,
			),
			'', $this->template_base
		);
	}

	public function trigger( $order_id, $order = false ) {
		$this->setup_locale();
		if ( $order_id && ! is_a( $order, 'WC_Order' ) ) {
			$order = wc_get_order( $order_id );
		}

		if ( is_a( $order, 'WC_Order' ) ) {
			$this->object                         = $order;
			$this->recipient                      = $this->object->get_billing_email();
			$this->placeholders['{order_date}']   = wc_format_datetime( $this->object->get_date_created() );
			$this->placeholders['{order_number}'] = $this->object->get_order_number();
		}

		if ( $this->is_enabled() && $this->get_recipient() ) {
			$this->send( $this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments() );
		}

		$this->restore_locale();
	}

}

return new ShippedOrder();
