<?php

use Grilabs_Shipmendo\ShipmentCompany;

function gl_shipmendo_send_sms( $post_id ) {
	if ( ! gl_shipmendo_is_cargo_sms_enabled() || ! function_exists( 'wp_sms_send_sms' ) ) {
		return;
	}

	$trackingNumber   = gl_shipmendo_get_order_cargo_tracking_number( $post_id );
	$cargoCompanyName = gl_shipmendo_get_order_cargo_company_info( $post_id );
	$order            = wc_get_order( $post_id );

	if ( $trackingNumber !== '' && $cargoCompanyName !== '' ) {
		$telNo  = gl_shipmendo_get_order_cargo_phone_number( $post_id );
		$msg    = gl_shipmendo_get_cargo_sms_message();
		$oldMsg = array(
			'{customer_name}',
			'{order_id}',
			'{order_number}',
			'{tracking_number}',
			'{cargo_company_info}',
			'{url}'
		);
		$newMsg = array(
			$order->get_formatted_billing_full_name(),
			$order->get_id(),
			$order->get_order_number(),
			$trackingNumber,
			strtoupper( $cargoCompanyName ),
			gl_shipmendo_get_cargo_tracking_url( $cargoCompanyName, $trackingNumber )
		);

		$msg = str_replace( $oldMsg, $newMsg, $msg );
		try {
			wp_sms_send_sms( $telNo, $msg );
			$note_text = sprintf( __( 'SMS sent to %s. Text: %s', 'shipmendo-lite' ), $telNo, $msg );
			$order->add_order_note( $note_text );
		} catch ( Exception $e ) {
			$order->add_order_note( $e->getMessage() );
		}
	}
}

function gl_shipmendo_send_email( $order_id, $status ) {
	if ( ! gl_shipmendo_is_cargo_email_enabled() ) {
		return;
	}

	$mailer = WC()->mailer()->get_emails();
	switch ( $status ) {
		case 'shipped2':
			$mailer['Shipped_Order']->trigger( $order_id );
			break;
	}
}

function gl_shipmendo_get_cargo_companies( $cargoName = null ) {
	if ( ! class_exists( '\Grilabs_Shipmendo\ShipmentCompany' ) ) {
		include dirname( __DIR__ ) . '/lib/ShipmentCompany.php';
	}
	$companies            = array();
	$companies['aras']    = new ShipmentCompany( 'aras', __( 'Aras Kargo', 'shipmendo-lite' ), gl_get_shipmendo_plugin_assets( '/images/aras.png' ), 'https://kargotakip.araskargo.com.tr/?code=[code]' );
	$companies['mng']     = new ShipmentCompany( 'mng', __( 'MNG Kargo', 'shipmendo-lite' ), gl_get_shipmendo_plugin_assets( '/images/mng.png' ), 'https://kargotakip.mngkargo.com.tr/?takipNo=[code]' );
	$companies['ptt']     = new ShipmentCompany( 'ptt', __( 'PTT Kargo', 'shipmendo-lite' ), gl_get_shipmendo_plugin_assets( '/images/ptt.png' ), 'https://gonderitakip.ptt.gov.tr/Track/Verify?q=[code]' );
	$companies['surat']   = new ShipmentCompany( 'surat', __( 'Sürat Kargo', 'shipmendo-lite' ), gl_get_shipmendo_plugin_assets( '/images/surat.png' ), 'https://www.suratkargo.com.tr/KargoTakip/?kargotakipno=[code]' );
	$companies['ups']     = new ShipmentCompany( 'ups', __( 'UPS Kargo', 'shipmendo-lite' ), gl_get_shipmendo_plugin_assets( '/images/ups.png' ), 'https://www.ups.com.tr/WaybillSorgu.aspx?Waybill=[code]' );
	$companies['yurtici'] = new ShipmentCompany( 'yurtici', __( 'Yurtiçi Kargo', 'shipmendo-lite' ), gl_get_shipmendo_plugin_assets( '/images/yurtici.png' ), 'https://yurti.ci/[code]' );

	return $cargoName !== null && isset( $companies[ $cargoName ] ) ? $companies[ $cargoName ] : $companies;
}

function gl_shipmendo_get_cargo_tracking_url( $cargoCompanyInfo, $trackingNumber ) {
	$cargo = gl_shipmendo_get_cargo_companies( $cargoCompanyInfo );
	$url   = str_replace( '[code]', $trackingNumber, $cargo->getTrackingUrlBase() );

	return apply_filters( 'cargo_tracking_url', $url, $cargoCompanyInfo, $trackingNumber );
}

function gl_shipmendo_get_cargo_sms_message() {
	return get_option( '_cargo_tracking_sms_message' );
}

function gl_shipmendo_is_cargo_sms_enabled() {
	return get_option( '_cargo_tracking_sms_enabled', 'off' ) === "on";
}

function gl_shipmendo_is_cargo_email_enabled() {
	return get_option( '_cargo_tracking_email_enabled', 'off' ) === "on";
}

function gl_shipmendo_get_cargo_default_company_name() {
	return get_option( '_cargo_tracking_default_cargo_company' );
}

function gl_shipmendo_get_order_cargo_company_info( $order_id ) {
	$company = get_post_meta( $order_id, '_cargo_company_info', true );
	if ( empty( $company ) ) {
		$company = gl_shipmendo_get_cargo_default_company_name();
	}

	return $company;
}

function gl_shipmendo_get_order_cargo_tracking_number( $order_id ) {
	return get_post_meta( $order_id, '_cargo_tracking_number', true );
}

function gl_shipmendo_get_order_cargo_phone_number( $order_id ) {
	return get_post_meta( $order_id, '_billing_phone', true );
}

function gl_shipmendo_get_order_cargo_tracking_url( $post_id ) {
	$trackingNumber   = gl_shipmendo_get_order_cargo_tracking_number( $post_id );
	$cargoCompanyInfo = gl_shipmendo_get_order_cargo_company_info( $post_id );

	return gl_shipmendo_get_cargo_tracking_url( $cargoCompanyInfo, $trackingNumber );
}




